@@ -218,6 +218,7 @@ class Resource(object):
     Base class representing a CloudFormation resource that can be exported
     """
 
+    RESOURCE_TYPE = None
     PROPERTY_NAME = None
     PACKAGE_NULL_PROPERTY = True
     # Set this property to True in base class if you want the exporter to zip
@@ -306,11 +307,13 @@ class ResourceWithS3UrlDict(Resource):
 
 
 class ServerlessFunctionResource(Resource):
+    RESOURCE_TYPE = "AWS::Serverless::Function"
     PROPERTY_NAME = "CodeUri"
     FORCE_ZIP = True
 
 
 class ServerlessApiResource(Resource):
+    RESOURCE_TYPE = "AWS::Serverless::Api"
     PROPERTY_NAME = "DefinitionUri"
     # Don't package the directory if DefinitionUri is omitted.
     # Necessary to support DefinitionBody
@@ -318,10 +321,31 @@ class ServerlessApiResource(Resource):
 
 
 class GraphQLSchemaResource(Resource):
+    RESOURCE_TYPE = "AWS::AppSync::GraphQLSchema"
     PROPERTY_NAME = "DefinitionS3Location"
+    # Don't package the directory if DefinitionS3Location is omitted.
+    # Necessary to support Definition
+    PACKAGE_NULL_PROPERTY = False
+
+
+class AppSyncResolverRequestTemplateResource(Resource):
+    RESOURCE_TYPE = "AWS::AppSync::Resolver"
+    PROPERTY_NAME = "RequestMappingTemplateS3Location"
+    # Don't package the directory if RequestMappingTemplateS3Location is omitted.
+    # Necessary to support RequestMappingTemplate
+    PACKAGE_NULL_PROPERTY = False
+
+
+class AppSyncResolverResponseTemplateResource(Resource):
+    RESOURCE_TYPE = "AWS::AppSync::Resolver"
+    PROPERTY_NAME = "ResponseMappingTemplateS3Location"
+    # Don't package the directory if ResponseMappingTemplateS3Location is omitted.
+    # Necessary to support ResponseMappingTemplate
+    PACKAGE_NULL_PROPERTY = False
 
 
 class LambdaFunctionResource(ResourceWithS3UrlDict):
+    RESOURCE_TYPE = "AWS::Lambda::Function"
     PROPERTY_NAME = "Code"
     BUCKET_NAME_PROPERTY = "S3Bucket"
     OBJECT_KEY_PROPERTY = "S3Key"
@@ -330,6 +354,7 @@ class LambdaFunctionResource(ResourceWithS3UrlDict):
 
 
 class ApiGatewayRestApiResource(ResourceWithS3UrlDict):
+    RESOURCE_TYPE = "AWS::ApiGateway::RestApi"
     PROPERTY_NAME = "BodyS3Location"
     PACKAGE_NULL_PROPERTY = False
     BUCKET_NAME_PROPERTY = "Bucket"
@@ -338,6 +363,7 @@ class ApiGatewayRestApiResource(ResourceWithS3UrlDict):
 
 
 class ElasticBeanstalkApplicationVersion(ResourceWithS3UrlDict):
+    RESOURCE_TYPE = "AWS::ElasticBeanstalk::ApplicationVersion"
     PROPERTY_NAME = "SourceBundle"
     BUCKET_NAME_PROPERTY = "S3Bucket"
     OBJECT_KEY_PROPERTY = "S3Key"
@@ -349,6 +375,7 @@ class CloudFormationStackResource(Resource):
     Represents CloudFormation::Stack resource that can refer to a nested
     stack template via TemplateURL property.
     """
+    RESOURCE_TYPE = "AWS::CloudFormation::Stack"
     PROPERTY_NAME = "TemplateURL"
 
     def __init__(self, uploader):
@@ -393,17 +420,17 @@ class CloudFormationStackResource(Resource):
                     parts["Key"], parts.get("Version", None))
 
 
-EXPORT_DICT = {
-    "AWS::Serverless::Function": ServerlessFunctionResource,
-    "AWS::Serverless::Api": ServerlessApiResource,
-    "AWS::AppSync::GraphQLSchema": GraphQLSchemaResource,
-    "AWS::ApiGateway::RestApi": ApiGatewayRestApiResource,
-    "AWS::Lambda::Function": LambdaFunctionResource,
-    "AWS::ElasticBeanstalk::ApplicationVersion":
-        ElasticBeanstalkApplicationVersion,
-    "AWS::CloudFormation::Stack": CloudFormationStackResource
-}
-
+EXPORT_LIST = [
+    ServerlessFunctionResource,
+    ServerlessApiResource,
+    GraphQLSchemaResource,
+    AppSyncResolverRequestTemplateResource,
+    AppSyncResolverResponseTemplateResource,
+    ApiGatewayRestApiResource,
+    LambdaFunctionResource,
+    ElasticBeanstalkApplicationVersion,
+    CloudFormationStackResource
+]
 
 class Template(object):
     """
@@ -411,7 +438,7 @@ class Template(object):
     """
 
     def __init__(self, template_path, parent_dir, uploader,
-                 resources_to_export=EXPORT_DICT):
+                 resources_to_export=EXPORT_LIST):
         """
         Reads the template and makes it ready for export
         """
@@ -448,10 +475,12 @@ class Template(object):
             resource_type = resource.get("Type", None)
             resource_dict = resource.get("Properties", None)
 
-            if resource_type in self.resources_to_export:
+            for exporter_class in self.resources_to_export:
+                if exporter_class.RESOURCE_TYPE != resource_type:
+                    continue
+
                 # Export code resources
-                exporter = self.resources_to_export[resource_type](
-                        self.uploader)
+                exporter = exporter_class(self.uploader)
                 exporter.export(resource_id, resource_dict, self.template_dir)
 
         return self.template_dict
